@@ -10,6 +10,7 @@ service UnitTestModelController {
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModel) {}
     rpc Update(UnitTestModel) returns (UnitTestModel) {}
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
+    rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModel) {}
 }
 
 message UnitTestModel {
@@ -34,14 +35,15 @@ message UnitTestModelDestroyRequest {
     int32 id = 1;
 }
 
+message UnitTestModelStreamRequest {
+}
+
 """
 
 SIMPLE_APP_MODEL_NO_GENERATION = """syntax = "proto3";
 
 package fakeapp;
 
-import "google/protobuf/empty.proto";
-
 """
 
 SIMPLE_APP_MODEL_GENERATED = """syntax = "proto3";
@@ -56,6 +58,7 @@ service UnitTestModelController {
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModel) {}
     rpc Update(UnitTestModel) returns (UnitTestModel) {}
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
+    rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModel) {}
 }
 
 message UnitTestModel {
@@ -80,6 +83,9 @@ message UnitTestModelDestroyRequest {
     int32 id = 1;
 }
 
+message UnitTestModelStreamRequest {
+}
+
 """
 
 ALL_APP_GENERATED = """syntax = "proto3";
@@ -87,6 +93,7 @@ ALL_APP_GENERATED = """syntax = "proto3";
 package fakeapp;
 
 import "google/protobuf/empty.proto";
+import "google/protobuf/struct.proto";
 
 service UnitTestModelController {
     rpc List(UnitTestModelListRequest) returns (UnitTestModelListResponse) {}
@@ -94,6 +101,7 @@ service UnitTestModelController {
     rpc Retrieve(UnitTestModelRetrieveRequest) returns (UnitTestModel) {}
     rpc Update(UnitTestModel) returns (UnitTestModel) {}
     rpc Destroy(UnitTestModelDestroyRequest) returns (google.protobuf.Empty) {}
+    rpc Stream(UnitTestModelStreamRequest) returns (stream UnitTestModel) {}
 }
 
 service ForeignModelController {
@@ -117,6 +125,14 @@ service RelatedFieldModelController {
     rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
 }
 
+service SpecialFieldsModelController {
+    rpc List(SpecialFieldsModelListRequest) returns (SpecialFieldsModelListResponse) {}
+    rpc Create(SpecialFieldsModel) returns (SpecialFieldsModel) {}
+    rpc Retrieve(SpecialFieldsModelRetrieveRequest) returns (SpecialFieldsModel) {}
+    rpc Update(SpecialFieldsModel) returns (SpecialFieldsModel) {}
+    rpc Destroy(SpecialFieldsModelDestroyRequest) returns (google.protobuf.Empty) {}
+}
+
 message UnitTestModel {
     int32 id = 1;
     string title = 2;
@@ -139,6 +155,9 @@ message UnitTestModelDestroyRequest {
     int32 id = 1;
 }
 
+message UnitTestModelStreamRequest {
+}
+
 message ForeignModel {
     string uuid = 1;
     string name = 2;
@@ -189,6 +208,8 @@ message RelatedFieldModelListResponse {
     string uuid = 1;
     string foreign = 2;
     repeated string many_many = 3;
+    string custom_field_name = 4;
+    repeated string list_custom_field_name = 5;
 }
 
 message RelatedFieldModelRetrieveRequest {
@@ -199,14 +220,39 @@ message RelatedFieldModelDestroyRequest {
     string uuid = 1;
 }
 
+message SpecialFieldsModel {
+    string uuid = 1;
+    google.protobuf.Struct meta_datas = 2;
+    repeated int32 list_datas = 3;
+}
+
+message SpecialFieldsModelListRequest {
+}
+
+message SpecialFieldsModelListResponse {
+    repeated SpecialFieldsModel results = 1;
+    int32 count = 2;
+}
+
+message SpecialFieldsModelRetrieveRequest {
+    string uuid = 1;
+}
+
+message SpecialFieldsModelDestroyRequest {
+    string uuid = 1;
+}
+
+message ImportStructEvenInArrayModel {
+    string id = 1;
+    repeated google.protobuf.Struct this_is_crazy = 2;
+}
+
 """
 
 CUSTOM_APP_MODEL_GENERATED = """syntax = "proto3";
 
 package fakeapp;
 
-import "google/protobuf/empty.proto";
-
 service ForeignModelController {
     rpc List(ForeignModelListRequest) returns (ForeignModelListResponse) {}
     rpc Retrieve(ForeignModelRetrieveRequestCustom) returns (ForeignModelRetrieveRequestCustom) {}
@@ -257,6 +303,8 @@ message RelatedFieldModelListResponse {
     string uuid = 1;
     string foreign = 2;
     repeated string many_many = 3;
+    string custom_field_name = 4;
+    repeated string list_custom_field_name = 5;
 }
 
 message RelatedFieldModelRetrieveRequest {
@@ -268,3 +316,16 @@ message RelatedFieldModelDestroyRequest {
 }
 
 """
+
+MODEL_WITH_STRUCT_IMORT_IN_ARRAY = """syntax = "proto3";
+
+package fakeapp;
+
+import "google/protobuf/struct.proto";
+
+message ImportStructEvenInArrayModel {
+    string id = 1;
+    repeated google.protobuf.Struct this_is_crazy = 2;
+}
+
+"""
