@@ -9,6 +9,7 @@ from .assets.generated_protobuf_files import (
     ALL_APP_GENERATED,
     CUSTOM_APP_MODEL_GENERATED,
     MODEL_WITH_M2M_GENERATED,
+    MODEL_WITH_STRUCT_IMORT_IN_ARRAY,
     SIMPLE_APP_MODEL_GENERATED,
     SIMPLE_APP_MODEL_NO_GENERATION,
     SIMPLE_MODEL_GENERATED,
@@ -19,7 +20,11 @@ class TestProtoGeneration(TestCase):
     def test_generate_one_model(self):
         self.maxDiff = None
         args = []
-        opts = {"model": "unittestmodel", "file": "proto/unittestmodel.proto"}
+        opts = {
+            "model": "unittestmodel",
+            "file": "proto/unittestmodel.proto",
+            "generate_python": False,
+        }
         with patch("builtins.open", mock_open()) as m:
             call_command("generateproto", *args, **opts)
 
@@ -77,7 +82,7 @@ class TestProtoGeneration(TestCase):
         self.maxDiff = None
 
         args = []
-        opts = {"app": "fakeapp", "model": "RelatedFieldModel"}
+        opts = {"app": "fakeapp", "model": "RelatedFieldModel", "generate_python": False}
         with patch("builtins.open", mock_open()) as m:
             call_command("generateproto", *args, **opts)
 
@@ -94,7 +99,7 @@ class TestProtoGeneration(TestCase):
         self.maxDiff = None
 
         args = []
-        opts = {"app": "fakeapp", "model": "NotDisplayedModel"}
+        opts = {"app": "fakeapp", "model": "NotDisplayedModel", "generate_python": False}
         with patch("builtins.open", mock_open()) as m:
             call_command("generateproto", *args, **opts)
 
@@ -109,7 +114,7 @@ class TestProtoGeneration(TestCase):
     def test_generate_one_app_one_model(self):
         self.maxDiff = None
         args = []
-        opts = {"app": "fakeapp", "model": "unittestmodel"}
+        opts = {"app": "fakeapp", "model": "unittestmodel", "generate_python": False}
         with patch("builtins.open", mock_open()) as m:
             call_command("generateproto", *args, **opts)
 
@@ -126,7 +131,7 @@ class TestProtoGeneration(TestCase):
         self.maxDiff = None
 
         args = []
-        opts = {"app": "fakeapp"}
+        opts = {"app": "fakeapp", "generate_python": False}
         with patch("builtins.open", mock_open()) as m:
             call_command("generateproto", *args, **opts)
 
@@ -142,7 +147,7 @@ class TestProtoGeneration(TestCase):
     def test_generate_one_app_one_model_customized(self):
         self.maxDiff = None
         args = []
-        opts = {"app": "fakeapp", "model": "ForeignModel"}
+        opts = {"app": "fakeapp", "model": "ForeignModel", "generate_python": False}
         with patch("builtins.open", mock_open()) as m:
             call_command("generateproto", *args, **opts)
 
@@ -154,3 +159,23 @@ class TestProtoGeneration(TestCase):
 
         called_with_data = handle.write.call_args[0][0]
         self.assertEqual(called_with_data, CUSTOM_APP_MODEL_GENERATED)
+
+    def test_generate_one_app_one_model_import_struct_in_array(self):
+        self.maxDiff = None
+        args = []
+        opts = {
+            "app": "fakeapp",
+            "model": "ImportStructEvenInArrayModel",
+            "generate_python": False,
+        }
+        with patch("builtins.open", mock_open()) as m:
+            call_command("generateproto", *args, **opts)
+
+        # this is done to avoid error on different absolute path
+        assert m.mock_calls[0].args[0].endswith("fakeapp/grpc/fakeapp.proto")
+        assert m.mock_calls[0].args[1] == "w"
+
+        handle = m()
+
+        called_with_data = handle.write.call_args[0][0]
+        self.assertEqual(called_with_data, MODEL_WITH_STRUCT_IMORT_IN_ARRAY)
